@@ -2,13 +2,12 @@
 
 namespace MediaWiki\Extension\ConfirmEdit\hCaptcha;
 
-use MediaWiki\Html\Html;
+use MediaWiki\Extension\ConfirmEdit\hCaptcha\Services\HCaptchaOutput;
 use MediaWiki\HTMLForm\HTMLFormField;
+use MediaWiki\MediaWikiServices;
+use MediaWiki\Message\Message;
 
 class HTMLHCaptchaField extends HTMLFormField {
-	/** @var string Public key parameter to be passed to hCaptcha. */
-	protected $key;
-
 	/** @var string Error returned by hCaptcha in the previous round. */
 	protected $error;
 
@@ -22,34 +21,32 @@ class HTMLHCaptchaField extends HTMLFormField {
 		$params += [ 'error' => null ];
 		parent::__construct( $params );
 
-		$this->key = $params['key'];
 		$this->error = $params['error'];
 
 		$this->mName = 'h-captcha-response';
 	}
 
+	/**
+	 * Show a more informative error for form submissions without an hCaptcha token,
+	 * which may be from non-JS clients.
+	 * @inheritDoc
+	 */
+	public function validate( $value, $alldata ): bool|Message|string {
+		if ( !$value ) {
+			return $this->msg( 'hcaptcha-missing-token' );
+		}
+
+		return parent::validate( $value, $alldata );
+	}
+
 	/** @inheritDoc */
 	public function getInputHTML( $value ) {
 		$out = $this->mParent->getOutput();
 
-		$config = $this->mParent->getConfig();
-		$url = $config->get( 'HCaptchaApiUrl' );
-		$out->addHeadItem(
-			'h-captcha',
-			"<script src=\"$url\" async defer></script>"
-		);
+		/** @var HCaptchaOutput $output */
+		$output = MediaWikiServices::getInstance()->get( 'HCaptchaOutput' )
+			->addHCaptchaToForm( $out, (bool)$this->error );
 		HCaptcha::addCSPSources( $out->getCSP() );
-		$output = Html::element( 'div', [
-			'class' => [
-				'h-captcha',
-				'mw-confirmedit-captcha-fail' => (bool)$this->error,
-			],
-			'data-sitekey' => $this->key,
-		] );
-
-		if ( $config->get( 'HCaptchaPassiveMode' ) ) {
-			$output .= $this->getMessage( 'hcaptcha-privacy-policy' )->parse();
-		}
 
 		return $output;
 	}
