@@ -5,8 +5,10 @@ namespace MediaWiki\Extension\Nuke\Test\Integration;
 use MediaWiki\Context\RequestContext;
 use MediaWiki\Exception\ErrorPageError;
 use MediaWiki\Exception\PermissionsError;
+use MediaWiki\Extension\Nuke\NukeConfigNames;
 use MediaWiki\Extension\Nuke\SpecialNuke;
 use MediaWiki\Extension\Nuke\Test\NukeIntegrationTest;
+use MediaWiki\MainConfigNames;
 use MediaWiki\Permissions\UltimateAuthority;
 use MediaWiki\Request\FauxRequest;
 use MediaWiki\Tests\User\TempUser\TempUserTestTrait;
@@ -28,6 +30,14 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 	use NukeIntegrationTest;
 	use TempUserTestTrait;
 
+	/**
+	 * @before
+	 * @return void
+	 */
+	public function nukeUISetUp() {
+		$this->overrideConfigValue( NukeConfigNames::UIType, null );
+	}
+
 	protected function newSpecialPage(): SpecialNuke {
 		$services = $this->getServiceContainer();
 
@@ -42,7 +52,7 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 			$services->getNamespaceInfo(),
 			$services->getContentLanguage(),
 			$services->getRedirectLookup(),
-			$services->getService( 'NukeIPLookup' ),
+			$services->getService( 'NukeIPLookup' )
 		);
 	}
 
@@ -298,7 +308,11 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		$this->assertStringContainsString( 'Target1', $html );
 		$this->assertStringContainsString( 'Target2', $html );
 
-		$this->assertEquals( 2, substr_count( $html, '(nuke-editby: 127.0.0.1)' ) );
+		$this->assertEquals(
+			2,
+			substr_count( $html, 'nuke-editby: 127.0.0.1' ),
+			"Failed asserting that the IP address is shown twice in '$html'"
+		);
 	}
 
 	public static function provideListTargetNormalizeUser() {
@@ -368,7 +382,11 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		$this->checkForValidationMessages( $html );
 
 		$year = gmdate( 'Y' );
-		$this->assertEquals( 2, substr_count( $html, "(nuke-editby: ~$year-1)" ) );
+		$this->assertEquals(
+			2,
+			substr_count( $html, "~$year-1" ),
+			"Failed asserting that the temporary account is shown twice in '$html'"
+		);
 
 		$this->assertStringContainsString( 'Target1', $html );
 		$this->assertStringContainsString( 'Target2', $html );
@@ -415,8 +433,16 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		$this->checkForValidationMessages( $html );
 
 		$year = gmdate( 'Y' );
-		$this->assertSame( 1, substr_count( $html, "(nuke-editby: ~$year-1)" ) );
-		$this->assertSame( 1, substr_count( $html, ' (nuke-editby: 1.2.3.4)' ) );
+		$this->assertSame(
+			1,
+			substr_count( $html, "~$year-1" ),
+			"Failed asserting that the temporary account name is shown once in '$html'"
+		);
+		$this->assertSame(
+			1,
+			substr_count( $html, 'nuke-editby: 1.2.3.4' ),
+			"Failed asserting that the IP address is shown once in '$html'"
+		);
 
 		// They should all show up together
 		$this->assertStringContainsString( 'Target1', $html );
@@ -779,6 +805,8 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 			[ $created, $wanted ] = is_array( $testData ) ?
 				$testData : [ $testData, $testData ];
 
+			// Disable case-sensitive page titles
+			$this->overrideConfigValue( 'CapitalLinks', true );
 			$this->overrideConfigValue( 'LanguageCode', $lang );
 			$this->editPage( $created, 'test' );
 
@@ -814,7 +842,11 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		// enforced on the initial 'pages' query and no associated pages are selected.
 		$this->checkForValidationMessages( $html );
 
-		$this->assertEquals( 2, substr_count( $html, '<li>' ) );
+		$this->assertEquals(
+			2,
+			substr_count( $html, '<li>' ),
+			"Failed asserting that two entries are shown in '$html'"
+		);
 	}
 
 	public function testListLimitWithHooks() {
@@ -838,7 +870,11 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		[ $html ] = $this->executeSpecialPage( '', $request, 'qqx', $performer );
 		$this->checkForValidationMessages( $html );
 
-		$this->assertEquals( 2, substr_count( $html, '<li>' ) );
+		$this->assertEquals(
+			2,
+			substr_count( $html, '<li>' ),
+			"Failed asserting that two entries are shown in '$html'"
+		);
 	}
 
 	public function testListMaxAge() {
@@ -1632,6 +1668,8 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 	}
 
 	public function testListFiles() {
+		$this->overrideConfigValue( MainConfigNames::EnableUploads, true );
+
 		$testFileName = $this->uploadTestFile()['title']->getPrefixedText();
 
 		$admin = $this->getTestSysop()->getUser();
@@ -1920,6 +1958,8 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		$testUser = $this->getTestUser( "user" )->getUser();
 		$testUserName = $testUser->getName();
 
+		$this->overrideConfigValue( MainConfigNames::EnableUploads, true );
+
 		$pages[] = $this->uploadTestFile( $testUser )[ 'title' ];
 		$pages[] = $this->insertPage( 'Page123', 'Test', NS_MAIN, $testUser )[ 'title' ];
 		$pages[] = $this->insertPage( 'Paging456', 'Test', NS_MAIN, $testUser )[ 'title' ];
@@ -1953,6 +1993,8 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 		$testUser = $this->getTestUser( "user" )->getUser();
 		$testUserName = $testUser->getName();
 
+		$this->overrideConfigValue( MainConfigNames::EnableUploads, true );
+
 		$pages[] = $this->uploadTestFile( $testUser )[ 'title' ];
 		$pages[] = $this->insertPage( 'Page123', 'Test', NS_MAIN, $testUser )[ 'title' ];
 		$pages[] = $this->insertPage( 'Paging456', 'Test', NS_MAIN, $testUser )[ 'title' ];
@@ -2102,6 +2144,8 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 	}
 
 	public function testDeleteFiles() {
+		$this->overrideConfigValue( MainConfigNames::EnableUploads, true );
+
 		$testFileName = $this->uploadTestFile()['title']->getPrefixedText();
 
 		$admin = $this->getTestSysop()->getUser();
@@ -2338,7 +2382,7 @@ class SpecialNukeHTMLFormTest extends SpecialPageTestBase {
 	 * @param string[] $messages The i18n keys of the messages that should be found.
 	 * @return void
 	 */
-	private function checkForValidationMessages( string $html, ?array $messages = [] ) {
+	protected function checkForValidationMessages( string $html, ?array $messages = [] ) {
 		$errorMessages = [
 			"htmlform-user-not-valid",
 			"nuke-date-limited",
