@@ -17,7 +17,7 @@
  * @param {ve.dm.Model} model Model the item is related to
  * @param {Object} [config] Configuration options
  */
-ve.ui.MobileActionsContextItem = function VeUiMobileActionsContextItem( context, model, config ) {
+ve.ui.MobileActionsContextItem = function VeUiMobileActionsContextItem( context, model, config = {} ) {
 	// Parent constructor
 	ve.ui.MobileActionsContextItem.super.call( this, context, model, config );
 
