@@ -360,7 +360,8 @@ ve.ui.MWSaveDialog.prototype.swapPanel = function ( panel, noFocus ) {
 					title: ve.init.target.getPageName(),
 					prop: '',
 					summary: currentEditSummaryWikitext
-				} ).done( ( result ) => {
+				} );
+				this.editSummaryXhr.then( ( result ) => {
 					if ( result.parse.parsedsummary === '' ) {
 						this.$previewEditSummary.parent().addClass( 'oo-ui-element-hidden' );
 						this.$previewEditSummary.empty();
@@ -373,7 +374,7 @@ ve.ui.MWSaveDialog.prototype.swapPanel = function ( panel, noFocus ) {
 						this.$previewEditSummary.html( wrappedSummary );
 						ve.targetLinksToNewWindow( this.$previewEditSummary[ 0 ] );
 					}
-				} ).fail( () => {
+				}, () => {
 					this.$previewEditSummary.parent().addClass( 'oo-ui-element-hidden' );
 					this.$previewEditSummary.empty();
 				} ).always( () => {
@@ -493,7 +494,7 @@ ve.ui.MWSaveDialog.prototype.reset = function () {
  * @param {OO.ui.FieldLayout[]} checkboxFields Checkbox fields
  */
 ve.ui.MWSaveDialog.prototype.setupCheckboxes = function ( checkboxFields ) {
-	this.setupDeferred.done( () => {
+	this.setupDeferred.then( () => {
 		checkboxFields.forEach( ( field ) => {
 			this.$saveCheckboxes.append( field.$element );
 		} );
@@ -509,7 +510,7 @@ ve.ui.MWSaveDialog.prototype.setupCheckboxes = function ( checkboxFields ) {
  * @param {string} summary Edit summary to prefill
  */
 ve.ui.MWSaveDialog.prototype.setEditSummary = function ( summary ) {
-	this.setupDeferred.done( () => {
+	this.setupDeferred.then( () => {
 		this.editSummaryInput.setValue( summary );
 	} );
 };
@@ -907,10 +908,14 @@ ve.ui.MWSaveDialog.prototype.getActionProcess = function ( action ) {
 
 	if ( action === 'save' ) {
 		return new OO.ui.Process( () => {
-			const saveDeferred = ve.createDeferred();
-			this.clearMessage( 'keyboard-shortcut-submit' );
-			this.emit( 'save', saveDeferred );
-			return saveDeferred.promise();
+			if ( this.panels.getCurrentItem() !== this.savePanel ) {
+				this.swapPanel( 'save' );
+			} else {
+				const saveDeferred = ve.createDeferred();
+				this.clearMessage( 'keyboard-shortcut-submit' );
+				this.emit( 'save', saveDeferred );
+				return saveDeferred.promise();
+			}
 		} );
 	}
 	if ( action === 'review' || action === 'preview' || action === 'resolve' ) {
