@@ -5,7 +5,9 @@ namespace MediaWiki\Maintenance;
 use Exception;
 use LCStoreNull;
 use LogicException;
-use Maintenance;
+use MediaWiki;
+use MediaWiki\Config\Config;
+use MediaWiki\Deferred\DeferredUpdates;
 use MediaWiki\Logger\LoggerFactory;
 use MediaWiki\MainConfigNames;
 use MediaWiki\MediaWikiServices;
@@ -33,7 +35,7 @@ class MaintenanceRunner {
 	/**
 	 * The class name of the script to execute.
 	 *
-	 * @var ?string
+	 * @var ?class-string<Maintenance>
 	 */
 	private $scriptClass = null;
 
@@ -48,9 +50,8 @@ class MaintenanceRunner {
 
 	/** @var bool */
 	private $runFromWrapper = false;
-
-	/** @var bool */
 	private bool $withoutLocalSettings = false;
+	private ?Config $config = null;
 
 	/**
 	 * Default constructor. Children should call this *first* if implementing
@@ -63,6 +64,14 @@ class MaintenanceRunner {
 		$this->addDefaultParams();
 	}
 
+	private function getConfig(): Config {
+		if ( $this->config === null ) {
+			$this->config = $this->getServiceContainer()->getMainConfig();
+		}
+
+		return $this->config;
+	}
+
 	/**
 	 * Add the default parameters to the scripts
 	 */
@@ -94,7 +103,7 @@ class MaintenanceRunner {
 	 *
 	 * @return never
 	 */
-	private function showHelpAndExit( $code = 0 ) {
+	private function showHelpAndExit( $code = 0 ): never {
 		foreach ( $this->parameters->getErrors() as $error ) {
 			$this->error( "$error\n" );
 			$code = 1;
@@ -194,8 +203,6 @@ class MaintenanceRunner {
 	 *        not including the script itself.
 	 */
 	private function initInternal( string $script, array $scriptArgv ) {
-		global $wgCommandLineMode;
-
 		$this->script = $script;
 		$this->scriptArgv = $scriptArgv;
 
@@ -207,9 +214,7 @@ class MaintenanceRunner {
 		}
 
 		// make sure we clean up after ourselves.
-		register_shutdown_function( [ $this, 'cleanup' ] );
-
-		$wgCommandLineMode = true;
+		register_shutdown_function( $this->cleanup( ... ) );
 
 		// Turn off output buffering if it's on
 		while ( ob_get_level() > 0 ) {
@@ -217,7 +222,7 @@ class MaintenanceRunner {
 		}
 	}
 
-	private static function isAbsolutePath( $path ) {
+	private static function isAbsolutePath( string $path ): bool {
 		if ( str_starts_with( $path, '/' ) ) {
 			return true;
 		}
@@ -257,7 +262,7 @@ class MaintenanceRunner {
 		return $extension;
 	}
 
-	private function loadScriptFile( string $scriptFile ): string {
+	private function loadScriptFile( string $scriptFile ): ?string {
 		$maintClass = null;
 
 		// It's a file, include it
@@ -271,13 +276,7 @@ class MaintenanceRunner {
 			$scriptClass = $maintClass;
 		}
 
-		if ( !is_string( $scriptClass ) ) {
-			$this->error( "ERROR: The script file '{$scriptFile}' cannot be executed using MaintenanceRunner.\n" );
-			$this->error( "It does not set \$maintClass and does not return a class name.\n" );
-			$this->fatalError( "Try running it directly as a php script: php $scriptFile\n" );
-		}
-
-		return $scriptClass;
+		return is_string( $scriptClass ) ? $scriptClass : null;
 	}
 
 	private function splitScript( string $script ): array {
@@ -289,6 +288,13 @@ class MaintenanceRunner {
 		return [ null, $script ];
 	}
 
+	/**
+	 * @return string The value of the constant MW_INSTALL_PATH. This method mocked in unit tests.
+	 */
+	protected function getMwInstallPath(): string {
+		return MW_INSTALL_PATH;
+	}
+
 	private function expandScriptFile( string $scriptName, ?array $extension ): string {
 		// Append ".php" if not present
 		$scriptFile = $scriptName;
@@ -304,7 +310,7 @@ class MaintenanceRunner {
 				$scriptFile = dirname( $extension['path'] ) . "/maintenance/{$scriptFile}";
 			} else {
 				// It's a core script.
-				$scriptFile = MW_INSTALL_PATH . "/maintenance/{$scriptFile}";
+				$scriptFile = $this->getMwInstallPath() . "/maintenance/{$scriptFile}";
 			}
 		}
 
@@ -346,15 +352,14 @@ class MaintenanceRunner {
 			return;
 		}
 
+		$scriptClass = $this->expandScriptClass( $scriptName, null );
 		$scriptFile = $this->expandScriptFile( $scriptName, null );
 
-		$scriptClass = null;
-		if ( file_exists( $scriptFile ) ) {
-			$scriptClass = $this->loadScriptFile( $scriptFile );
-		}
-
-		if ( !$scriptClass ) {
-			$scriptClass = $this->expandScriptClass( $scriptName, null );
+		if ( !class_exists( $scriptClass ) && file_exists( $scriptFile ) ) {
+			$scriptFileClass = $this->loadScriptFile( $scriptFile );
+			if ( $scriptFileClass ) {
+				$scriptClass = $scriptFileClass;
+			}
 		}
 
 		// NOTE: class_exists will trigger auto-loading, so file-level code in the script file will run.
@@ -366,6 +371,9 @@ class MaintenanceRunner {
 		// Preloading failed. Let findScriptClass() try to find the script later.
 	}
 
+	/**
+	 * @return class-string<Maintenance>
+	 */
 	protected function getScriptClass(): string {
 		if ( $this->scriptClass === null ) {
 			if ( $this->runFromWrapper ) {
@@ -386,7 +394,7 @@ class MaintenanceRunner {
 	 * @internal
 	 * @param string $script
 	 *
-	 * @return string
+	 * @return class-string<Maintenance>
 	 */
 	protected function findScriptClass( string $script ): string {
 		[ $extName, $scriptName ] = $this->splitScript( $script );
@@ -401,15 +409,25 @@ class MaintenanceRunner {
 			$extension = null;
 		}
 
+		$scriptClass = $this->expandScriptClass( $scriptName, $extension );
 		$scriptFile = $this->expandScriptFile( $scriptName, $extension );
 
-		$scriptClass = null;
-		if ( file_exists( $scriptFile ) ) {
-			$scriptClass = $this->loadScriptFile( $scriptFile );
-		}
-
-		if ( !$scriptClass ) {
-			$scriptClass = $this->expandScriptClass( $scriptName, $extension );
+		if ( !class_exists( $scriptClass ) && file_exists( $scriptFile ) ) {
+			// The guessed class is not registered with the autoloader.
+			// Let's see if the script defines the class to use in the old way.
+			$scriptFileClass = $this->loadScriptFile( $scriptFile );
+			if ( !$scriptFileClass && class_exists( $scriptClass ) ) {
+				// It doesn't, but instead it contains the guessed class, so it should have been autoloaded.
+				$this->error( "WARNING: The script class '{$scriptClass}' is not registered with the autoloader.\n" );
+			} elseif ( !$scriptFileClass ) {
+				// It doesn't.
+				$this->error( "ERROR: The script file '{$scriptFile}' cannot be executed using MaintenanceRunner.\n" );
+				$this->error( "It does not set \$maintClass and does not return a class name.\n" );
+				$this->fatalError( "Try running it directly as a php script: php $scriptFile\n" );
+			} else {
+				// It does! We'll check whether the class really exists below.
+				$scriptClass = $scriptFileClass;
+			}
 		}
 
 		if ( !class_exists( $scriptClass ) ) {
@@ -421,8 +439,6 @@ class MaintenanceRunner {
 
 	/**
 	 * MW_FINAL_SETUP_CALLBACK handler, for setting up the Maintenance object.
-	 *
-	 * @param SettingsBuilder $settings
 	 */
 	public function setup( SettingsBuilder $settings ) {
 		// NOTE: this has to happen after the autoloader has been initialized.
@@ -467,7 +483,6 @@ class MaintenanceRunner {
 		// Basic checks and such
 		$this->scriptObject->setup();
 
-		// Set the memory limit
 		$this->adjustMemoryLimit();
 
 		// Override any config settings
@@ -476,8 +491,6 @@ class MaintenanceRunner {
 
 	/**
 	 * Returns the maintenance script name to show in the help message.
-	 *
-	 * @return string
 	 */
 	public function getName(): string {
 		// Once one of the init methods was called, getArg( 0 ) should always
@@ -486,32 +499,31 @@ class MaintenanceRunner {
 	}
 
 	/**
-	 * Normally we disable the memory_limit when running admin scripts.
-	 * Some scripts may wish to actually set a limit, however, to avoid
-	 * blowing up unexpectedly.
-	 * @see Maintenance::memoryLimit()
-	 * @return string
+	 * Adjusts PHP's memory limit to better suit our needs, if needed.
+	 *
+	 * @see Maintenance::memoryLimit
 	 */
-	private function memoryLimit() {
+	private function adjustMemoryLimit() {
 		if ( $this->parameters->hasOption( 'memory-limit' ) ) {
 			$limit = $this->parameters->getOption( 'memory-limit', 'max' );
 			$limit = trim( $limit, "\" '" ); // trim quotes in case someone misunderstood
-			return $limit;
+		} else {
+			$limit = $this->scriptObject->memoryLimit() ?: 'max';
 		}
-
-		$limit = $this->scriptObject->memoryLimit();
-		return $limit ?: 'max';
-	}
-
-	/**
-	 * Adjusts PHP's memory limit to better suit our needs, if needed.
-	 */
-	private function adjustMemoryLimit() {
-		$limit = $this->memoryLimit();
 		if ( $limit == 'max' ) {
 			$limit = -1; // no memory limit
 		}
 		if ( $limit != 'default' ) {
+			// NOTE: This should not override $wgMemoryLimit and ride the wfMemoryLimit() call in Setup.php.
+			//
+			// We are still in MW_FINAL_SETUP_CALLBACK in Setup.php, before that calls wfMemoryLimit(),
+			// and we can still set $wgMemoryLimit here or in MaintenanceRunner::overrideConfig.
+			// But, $wgMemoryLimit is a way to *raise* the memory limit, mainly for web requests
+			// where the system default is often less than what we need.
+			//
+			// Maintenance::memoryLimit, however, is to *lower* the memory limit (often -1 for PHP-CLI).
+			// If we override $wgMemoryLimit and let Setup.php call wfMemoryLimit, it would do nothing
+			// when memory_limit=-1 and run maintenance scripts with unlimited memory.
 			ini_set( 'memory_limit', $limit );
 		}
 	}
@@ -524,7 +536,7 @@ class MaintenanceRunner {
 	 * @return void
 	 */
 	public function defineSettings() {
-		global $wgCommandLineMode, $IP;
+		global $IP;
 
 		if ( $this->parameters->hasOption( 'conf' ) ) {
 			// Define the constant instead of directly setting $settingsFile
@@ -569,7 +581,6 @@ class MaintenanceRunner {
 			}
 			$this->withoutLocalSettings = true;
 		}
-		$wgCommandLineMode = true;
 	}
 
 	/**
@@ -580,17 +591,17 @@ class MaintenanceRunner {
 	public static function emulateConfig( SettingsBuilder $settings ) {
 		// NOTE: The config schema is already loaded at this point, so default values are known.
 
-		// Server must be set, but we don't care to what
-		$settings->overrideConfigValue( 'Server', 'https://unknown.invalid' );
-
-		// If InvalidateCacheOnLocalSettingsChange is enabled, filemtime( MW_CONFIG_FILE ),
-		// which will produce a warning if there is no settings file.
-		$settings->overrideConfigValue( 'InvalidateCacheOnLocalSettingsChange', false );
+		$settings->overrideConfigValues( [
+			// Server must be set, but we don't care to what
+			MainConfigNames::Server => 'https://unknown.invalid',
+			// If InvalidateCacheOnLocalSettingsChange is enabled, filemtime( MW_CONFIG_FILE ),
+			// which will produce a warning if there is no settings file.
+			MainConfigNames::InvalidateCacheOnLocalSettingsChange => false,
+		] );
 	}
 
 	/**
 	 * @param SettingsBuilder $settingsBuilder
-	 *
 	 * @return void
 	 */
 	private function overrideConfig( SettingsBuilder $settingsBuilder ) {
@@ -626,6 +637,10 @@ class MaintenanceRunner {
 		$this->scriptObject->finalSetup( $settingsBuilder );
 	}
 
+	private function getServiceContainer(): MediaWikiServices {
+		return MediaWikiServices::getInstance();
+	}
+
 	/**
 	 * Run the maintenance script.
 	 *
@@ -641,7 +656,7 @@ class MaintenanceRunner {
 	 *         passed through from Maintenance::execute().
 	 */
 	public function run(): bool {
-		$config = MediaWikiServices::getInstance()->getMainConfig();
+		$config = $this->getConfig();
 
 		// Apply warning thresholds and output mode to Profiler.
 		// This MUST happen after Setup.php calls MaintenanceRunner::setup,
@@ -685,7 +700,7 @@ class MaintenanceRunner {
 				print_r( $GLOBALS );
 			}
 
-			$this->scriptObject->shutdown();
+			$this->shutdown();
 
 			return $success;
 		} catch ( Exception $ex ) {
@@ -712,14 +727,11 @@ class MaintenanceRunner {
 	 * @param int $exitCode PHP exit status. Should be in range 1-254.
 	 * @return never
 	 */
-	protected function fatalError( $msg, $exitCode = 1 ) {
+	protected function fatalError( $msg, $exitCode = 1 ): never {
 		$this->error( $msg );
 		exit( $exitCode );
 	}
 
-	/**
-	 * @param string $msg
-	 */
 	protected function error( string $msg ) {
 		// Print to stderr if possible, don't mix it in with stdout output.
 		if ( defined( 'STDERR' ) ) {
@@ -737,11 +749,9 @@ class MaintenanceRunner {
 	 * @return bool
 	 */
 	public static function shouldExecute() {
-		global $wgCommandLineMode;
-
 		if ( !function_exists( 'debug_backtrace' ) ) {
 			// If someone has a better idea...
-			return $wgCommandLineMode;
+			return MW_ENTRY_POINT === 'cli';
 		}
 
 		$bt = debug_backtrace();
@@ -764,10 +774,51 @@ class MaintenanceRunner {
 	 * @internal
 	 * @return void
 	 */
-	public function cleanup() {
+	protected function cleanup() {
 		if ( $this->scriptObject ) {
 			$this->scriptObject->cleanupChanneled();
 		}
 	}
 
+	/**
+	 * Call before exiting CLI process for the last DB commit, and flush
+	 * any remaining buffers and other deferred work.
+	 *
+	 * Equivalent to MediaWiki::restInPeace which handles shutdown for web requests,
+	 * and should perform the same operations and in the same order.
+	 *
+	 * @since 1.41
+	 */
+	private function shutdown() {
+		$lbFactory = null;
+		if (
+			$this->scriptObject->getDbType() !== Maintenance::DB_NONE &&
+			// Service might be disabled, e.g. when running install.php
+			!$this->getServiceContainer()->isServiceDisabled( 'DBLoadBalancerFactory' )
+		) {
+			$lbFactory = $this->getServiceContainer()->getDBLoadBalancerFactory();
+			if ( $lbFactory->isReadyForRoundOperations() ) {
+				$lbFactory->commitPrimaryChanges( get_class( $this ) );
+			}
+
+			DeferredUpdates::doUpdates();
+		}
+
+		// Handle profiler outputs
+		// NOTE: MaintenanceRunner ensures Profiler::setAllowOutput() during setup
+		$profiler = Profiler::instance();
+		$profiler->logData();
+		$profiler->logDataPageOutputOnly();
+
+		MediaWiki::emitBufferedStats(
+			$this->getServiceContainer()->getStatsFactory()
+		);
+
+		if ( $lbFactory ) {
+			if ( $lbFactory->isReadyForRoundOperations() ) {
+				$lbFactory->shutdown( $lbFactory::SHUTDOWN_NO_CHRONPROT );
+			}
+		}
+	}
+
 }
